@@ -1,18 +1,21 @@
-#! C:/Perl/bin/perl
+#!perl
 use Modern::Perl;
 use Moose::Util qw( with_traits );
 use lib '../lib', 'lib';
-use Data::Walk::Extracted v0.007;
-use Data::Walk::Graft v0.001;
+use Data::Walk::Extracted v0.011;
+use Data::Walk::Graft v0.007;
 use Data::Walk::Print v0.007;
 
 my  $gardener = with_traits( 
         'Data::Walk::Extracted', 
         ( 
             'Data::Walk::Graft', 
-            'Data::Walk::Print' 
+			'Data::Walk::Clone',
+            'Data::Walk::Print',
         ) 
-    )->new();
+    )->new(
+		sort_HASH => 1,# For demonstration consistency
+	);
 my  $tree_ref = {
         Helping =>{
             KeyTwo => 'A New Value',
@@ -28,12 +31,12 @@ my  $tree_ref = {
 $gardener->graft_data(
     scion_ref =>{
         Helping =>{
-            OtherKey => 'Something',
+            OtherKey => 'Otherthing',
         },
         MyArray =>[
             'IGNORE',
             {
-                AnotherKey => 'Chicken_Butt!',
+                What => 'Chicken_Butt!',
             },
             'IGNORE',
             'IGNORE',
@@ -42,5 +45,4 @@ $gardener->graft_data(
     }, 
     tree_ref  => $tree_ref,
 );
-$gardener->print_data( $tree_ref );
-say "Done";
\ No newline at end of file
+$gardener->print_data( $tree_ref );
\ No newline at end of file
